Initializers
------------------------

.. automodule:: flax.linen.initializers
.. currentmodule:: flax.linen.initializers

.. autofunction:: constant
.. autofunction:: delta_orthogonal
.. autofunction:: glorot_normal
.. autofunction:: glorot_uniform
.. autofunction:: he_normal
.. autofunction:: he_uniform
.. autofunction:: kaiming_normal
.. autofunction:: kaiming_uniform
.. autofunction:: lecun_normal
.. autofunction:: lecun_uniform
.. autofunction:: normal
.. autofunction:: truncated_normal
.. autofunction:: ones
.. autofunction:: ones_init
.. autofunction:: orthogonal
.. autofunction:: uniform
.. autofunction:: variance_scaling
.. autofunction:: xavier_normal
.. autofunction:: xavier_uniform
.. autofunction:: zeros
.. autofunction:: zeros_init
